@@ -6,16 +6,14 @@ from typing import Optional, Union
 
 import typer
 
-from openapi_python_client import MetaType
+from openapi_python_client import MetaType, __version__
 from openapi_python_client.config import Config, ConfigFile
 from openapi_python_client.parser.errors import ErrorLevel, GeneratorError, ParseError
 
-app = typer.Typer()
+app = typer.Typer(name="openapi-python-client")
 
 
 def _version_callback(value: bool) -> None:
-    from openapi_python_client import __version__
-
     if value:
         typer.echo(f"openapi-python-client version: {__version__}")
         raise typer.Exit()
@@ -63,7 +61,7 @@ def _process_config(
 # noinspection PyUnusedLocal
 
 
-@app.callback(name="openapi-python-client")
+@app.callback()
 def cli(
     version: bool = typer.Option(False, "--version", callback=_version_callback, help="Print the version and exit"),
 ) -> None:
@@ -153,7 +151,7 @@ def generate(
     ),
 ) -> None:
     """Generate a new OpenAPI Client library"""
-    from . import generate
+    from . import generate  # noqa: PLC0415
 
     config = _process_config(
         url=url,
